@@ -2382,6 +2382,15 @@ gtk_gs_start_scroll(GtkGS *gs)
                 gdk_draw_rectangle(gs->bpixmap, gs->psgc, FALSE,
                                    gs->scroll_start_x, gs->scroll_start_y,
                                    gs->scroll_width, gs->scroll_height);
+                rect.width = 1;
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+                rect.x = gs->scroll_start_x + gs->scroll_width;
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+                rect.x = gs->scroll_start_x + 1;
+                rect.width = gs->scroll_start_x + gs->scroll_width - 1;
+                rect.height = 1;
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+                rect.y = gs->scroll_start_y + gs->scroll_height;
                 gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
         }
 }
@@ -2404,6 +2413,15 @@ gtk_gs_end_scroll(GtkGS *gs)
                 gdk_draw_rectangle(gs->bpixmap, gs->psgc, FALSE,
                                    gs->scroll_start_x, gs->scroll_start_y,
                                    gs->scroll_width, gs->scroll_height);
+                rect.width = 1;
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+                rect.x = gs->scroll_start_x + gs->scroll_width;
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+                rect.x = gs->scroll_start_x + 1;
+                rect.width = gs->scroll_start_x + gs->scroll_width - 1;
+                rect.height = 1;
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+                rect.y = gs->scroll_start_y + gs->scroll_height;
                 gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
         }
         gs->scroll_start_x = -1;
